#
# spec file for package python-mutmut
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# tri.declarative is Python 3 only
%define skip_python2 1
# hammett requires python 3.7 or later
%define skip_python36 1
# pony not available for 3.12
%global skip_python312 1
Name:           python-mutmut
Version:        2.0.0
Release:        5.2
Summary:        Python mutation testing
License:        BSD-3-Clause
URL:            https://github.com/boxed/mutmut
Source:         https://github.com/boxed/mutmut/archive/%{version}.tar.gz
Patch1:         pr_134.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click
Requires:       python-glob2
Requires:       python-hammett
Requires:       python-junit-xml >= 1.8
Requires:       python-parso
Requires:       python-pony
Requires:       python-setuptools
Requires:       python-tri.declarative >= 3.0.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-coverage
Recommends:     python-pytest
Suggests:       python-pytest-cov
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module glob2}
BuildRequires:  %{python_module hammett}
BuildRequires:  %{python_module junit-xml >= 1.8}
BuildRequires:  %{python_module parso}
BuildRequires:  %{python_module pony}
BuildRequires:  %{python_module pytest >= 2.8.7}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module tri.declarative >= 3.0.0}
BuildRequires:  %{python_module whatthepatch >= 0.0.5}
BuildRequires:  ed
BuildRequires:  patch
# /SECTION
%python_subpackages

%description
Python mutation testing.

%prep
%setup -q -n mutmut-%{version}
%autopatch -p1
sed -i 's/==/>=/' *requirements.txt
# Remove maximum pins any anything that follows
sed -Ei 's/,?<=?.*$//' test_requirements.txt
sed -i '1{/^#!/d}' mutmut/__main__.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/mutmut
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative mutmut

%postun
%python_uninstall_alternative mutmut

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/mutmut
%{python_sitelib}/*

%changelog
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- skip building for 3.12
* Thu Mar 24 2022 pgajdos@suse.com
- python-mock is not required for build
* Tue Feb  2 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 (hammett requires python 3.7 or later)
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Mar 30 2020 pgajdos@suse.com
- version update to 2.0.0
  * New execution model. This should result in some modest speed improvements when using pytest.
  * A special execution mode when using the hammett test runner. This is MUCH MUCH faster. Please try it!
  * Dropped support for python < 3.7. If you need to use mutmut on older versions of python, please use mutmut 1.9.0
  * Some other speed improvements.
  * `mutmut run 7` will always rerun the mutant `7`
  * `mutmut show <filename>` to show all mutants for that file
  * `mutmut run <filename>` to run mutation testing on that file
  * New experimental plugin system: create a file `mutmut_config.py` in your base directory. In it you can have an `init()` function, and a `pre_mutation(context)` function. You can set `context.skip = True` to skip a mutant, and you can modify `context.config.runner`, this is useful to limit the tests. Check out the `Context` class for what information you get.
  * Better display of `mutmut show`/`mutmut result`
  * Fixed a spurious mutant on assigning a local variable with type annotations
  * mutmut now will rerun tests without mutation when tests have changed. This avoids a common pitfall of introducing a failing test and then having all mutants killed incorrectly
  * Added `mutmut html` report generation.
  * Bugfix for multiple assignment. Mutmut used to not handle `foo = bar = baz` correctly (Thanks Roxane Bellot!)
  * Bugfix for incorrect mutation of "in" operator (Thanks Roxane Bellot!)
  * Fixed bug where a mutant survived in the internal AST too long. This could cause mutmut to apply more than one mutant at a time.
  * Vastly improved startup performance when resuming a mutation run.
  * Added new experimental feature for advanced config at runtime of mutations
- modified patches
  %% pr_134.patch (extended)
- deleted patches
  - no-direct-python-call.patch (merged to pr_134.patch)
* Tue Oct 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.6.0:
  * Various minor fixes around in the package
- Remove merged patches pr_148.patch merged_4405bafe.patch
- Rebase patch pr_134.patch
- Add patch no-direct-python-call.patch to avoid direct calls
  to python binary
* Wed Aug  7 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.5.1
